@@ -24,6 +24,10 @@ is.wholenumber <- function(x, tol = .Machine$double.eps^0.5) {
 #' discount(rep(10, 5), .02, first = FALSE)
 #' 
 discount <- function(x, r, first = FALSE) {
+  stopifnot(
+    r >= 0,
+    r <= 1
+  )
   x / (1 + r) ^ (seq_along(x) - (1 - isTRUE(first)))
 }
 
